@@ -7,7 +7,6 @@ use warnings;
 use DBI;
 use Carp 'croak';
 use Exporter::NoWork;
-use Rose::DB::Object::Loader;
 
 use DB;
 use autodie;
@@ -193,6 +192,15 @@ SQL
 
     $dbh->do($sql_media);
 
+    my $login_table = <<"SQL";
+    CREATE TABLE IF NOT EXISTS user_login_history (
+    id INT AUTO_INCREMENT PRIMARY KEY,
+    user_id INT NOT NULL,
+    login_at DATETIME DEFAULT CURRENT_TIMESTAMP
+) ENGINE=InnoDB;
+SQL
+
+    $dbh->do($login_table);
     return 1;
 }
 
